==> dl.php?src=linea21_1_0.zip: linea21/public/tpl_publication.php <==
<div id="contenu">
<?php
//////////////////////////////////////////
/////affichage partie dossier
//////////////////////////////////////////

if($GLOBALS['activeitem']=='dossier' || $GLOBALS['activeitem']=='dossier-archives') {
	include_once('../publication/display.php');
	/** prparation des variables
	* 	$statut
	* 	$debut default 0
	* 	$id -> default -1
	* 	$filter default -1
	**/
	if($GLOBALS['activeitem']=='dossier') $statut='public';
	if($GLOBALS['activeitem']=='dossier-archives') $statut='archives_p';
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['debut'])) $debut=$_REQUEST['debut']; else $debut=0;
	if(isset($_REQUEST['filter'])) {
		if($_REQUEST['filter']==$GLOBALS['filter']['echelle']['linkvalue']) $filter='SCALE';
		if($_REQUEST['filter']==$GLOBALS['filter']['theme']['linkvalue']) $filter='THEME';
		if($_REQUEST['filter']==$GLOBALS['filter']['niveau']['linkvalue']) $filter='LEVEL';
	} else $filter=-1;

	
	/** Affichage du lien de consultation d'archives ( si ncessaire )
	*/
	if($GLOBALS['activeitem']!='dossier-archives')  {
		
		$link_archive= array('rub'=> $GLOBALS['links']['dossier-archives']['linkvalue']);
		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_archives'].'">'.$GLOBALS['lang']['divers']['goto_archives'].'</a>'.END_LINE;
		echo '</div>';
	}
	
	/** Affichage du lien de consultation d'archives ( si ncessaire )
	*/
	if($GLOBALS['activeitem']=='dossier-archives')  {
		
		$link_archive= array('rub'=> $GLOBALS['links']['dossier']['linkvalue']);
		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_currentlist'].'">'.$GLOBALS['lang']['divers']['goto_currentlist'].'</a>'.END_LINE;
		echo '</div>';
	}
	
	/** Affichage du Listing Des Dossiers et Dossiers archivs
	*/
	if((isset($_REQUEST['id']) && isset($_REQUEST['filter'])) || (!isset($_REQUEST['id']) && !isset($_REQUEST['filter']))) 
	{	
		DisplayListPublication($statut, $filter, $id, $debut);
	}
	
	
	/** Dtail d'un dossier
	*/
	if(isset($_REQUEST['id']) && !isset($_REQUEST['filter'])) {
		DisplayOnePublication($id);
		DisplayPublicationParts($id);
		echo '<div id="ressources">'.END_LINE;
		DisplayPublicationLinks($id);
		DisplayPublicationMulti($id);
		DisplayPublicationBiblio($id);
		echo '</div>'.END_LINE;
	}
}


//////////////////////////////////////////
/////affichage rapport de groupe de travail
//////////////////////////////////////////

if($GLOBALS['activeitem']=='rapport') {
	include_once('../workshoprep/display.php');
	
	/** prparation des variables
	* 	$id -> default -1
	**/
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	
	/** Dtail d'un rapport
	*/
	if(isset($_REQUEST['id'])) {
		DisplayOneWorkshopRep($id, 'P');
		DisplayWorkshopRepParts($id);
		echo '<div id="ressources">'.END_LINE;
		DisplayWorkshopRepLinks($id);
		DisplayWorkshopRepBiblio($id);
		echo '</div>'.END_LINE;
	}
	
}


//////////////////////////////////////////
/////	affichage Parties par parties 
/////	Rapports de groupe de travail et Dossiers
//////////////////////////////////////////

if($GLOBALS['activeitem']=='rapport-partie' || $GLOBALS['activeitem']=='dossier-partie') {
	include_once('../contents/display.php');
	
	/** prparation des variables
	* 	$id -> default -1
	*   $parentid -> default -1
	**/
	
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['parentid'])) $parentid=$_REQUEST['parentid']; else $parentid=-1;
	
	/** Dtail d'une partie
	*/
	if($GLOBALS['activeitem']=='rapport-partie')
	{
		include_once('../workshoprep/display.php');
		DisplayWorkshopNameAndGroup($parentid);
		DisplayWorkshopRepLinkinPart($id, $parentid, 'TEXT');
		DisplayOneWorkshopPart($id);
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkParts($id, $parentid, 'PREVIOUS', 'W');
		DisplayLinkParts($id, $parentid, 'NEXT', 'W');
		echo '</div>'.END_LINE;
		echo '<div id="ressources">'.END_LINE;
		DisplayWorkshopRepLinks($parentid);
		DisplayWorkshopRepBiblio($parentid);
		echo '</div>'.END_LINE;
		
	}
	if($GLOBALS['activeitem']=='dossier-partie') 
	{
		include_once('../publication/display.php');
		DisplayPublicationTitle($parentid);
		DisplayPublicationLinkinPart($id, $parentid, 'TEXT');
		DisplayOnePublicationPart($id);
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkParts($id, $parentid, 'PREVIOUS', 'P');
		DisplayLinkParts($id, $parentid, 'NEXT', 'P');
		echo '</div>'.END_LINE;
		echo '<div id="ressources">'.END_LINE;
		DisplayPublicationLinks($parentid);
		DisplayPublicationMulti($parentid);
		DisplayPublicationBiblio($parentid);
		echo '</div>'.END_LINE;
	}
	

	
}


//////////////////////////////////////////
/////affichage partie news
//////////////////////////////////////////

if($GLOBALS['activeitem']=='actualite' || $GLOBALS['activeitem']=='actualite-archives') {
	include_once('../news/display.php');
	/** prparation des variables
	* 	$statut
	* 	$debut default 0
	* 	$id -> default -1
	* 	$filter default -1
	**/
	if($GLOBALS['activeitem']=='actualite') $statut='public';
	if($GLOBALS['activeitem']=='actualite-archives') $statut='archives_p';
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['debut'])) $debut=$_REQUEST['debut']; else $debut=0;
	if(isset($_REQUEST['filter'])) {
		if($_REQUEST['filter']==$GLOBALS['filter']['echelle']['linkvalue']) $filter='SCALE';
		if($_REQUEST['filter']==$GLOBALS['filter']['theme']['linkvalue']) $filter='THEME';
		if($_REQUEST['filter']==$GLOBALS['filter']['niveau']['linkvalue']) $filter='LEVEL';
	} else $filter=-1;

	/** Affichage du lien de consultation d'archives ( si ncessaire )
	*/
	
	if($GLOBALS['activeitem']!='actualite-archives')  {

		$link_archive= array('rub'=> $GLOBALS['links']['actualite-archives']['linkvalue']);

		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_archives'].'">'.$GLOBALS['lang']['divers']['goto_archives'].'</a>'.END_LINE;
		echo '</div>';
		
	}
	
	
	/** Affichage du lien de consultation liste courante ( si ncessaire )
	*/
	if($GLOBALS['activeitem']=='actualite-archives')  {

		$link_archive= array('rub'=> $GLOBALS['links']['actualite']['linkvalue']);

		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_currentlist'].'">'.$GLOBALS['lang']['divers']['goto_currentlist'].'</a>'.END_LINE;
		echo '</div>';
		
	}
	
	/** Affichage du Listing Actualit + Archives
	*/
	
	if((isset($_REQUEST['id']) && isset($_REQUEST['filter'])) || (!isset($_REQUEST['id']) && !isset($_REQUEST['filter']))) 
	{	
		DisplayListNews($statut, $filter, $id, $debut);
	}
	
	
	/** Dtail d'une actualit
	*/
	if(isset($_REQUEST['id']) && !isset($_REQUEST['filter'])) {
		$news_statut=DisplayOneNews($id);
		echo '<hr />'.END_LINE;
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkNews($id, 'PREVIOUS', $news_statut);
		DisplayLinkNews($id, 'NEXT', $news_statut);
		echo '</div>'.END_LINE;
	}

	
}
?>
</div>

==> dl.php?src=linea21_1_1.zip: linea21/public/tpl_publication.php <==
<div id="contenu">
<?php
//////////////////////////////////////////
/////affichage partie dossier
//////////////////////////////////////////

if($GLOBALS['activeitem']=='dossier' || $GLOBALS['activeitem']=='dossier-archives') {
	include_once('../publication/display.php');
	/** préparation des variables
	* 	$statut
	* 	$debut default 0
	* 	$id -> default -1
	* 	$filter default -1
	**/
	if($GLOBALS['activeitem']=='dossier') $statut='public';
	if($GLOBALS['activeitem']=='dossier-archives') $statut='archives_p';
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['debut'])) $debut=$_REQUEST['debut']; else $debut=0;
	if(isset($_REQUEST['filter'])) {
		if($_REQUEST['filter']==$GLOBALS['filter']['echelle']['linkvalue']) $filter='SCALE';
		if($_REQUEST['filter']==$GLOBALS['filter']['theme']['linkvalue']) $filter='THEME';
		if($_REQUEST['filter']==$GLOBALS['filter']['niveau']['linkvalue']) $filter='LEVEL';
	} else $filter=-1;

	
	/** Affichage du lien de consultation d'archives ( si nécessaire )
	*/
	if($GLOBALS['activeitem']!='dossier-archives')  {
		
		$link_archive= array('rub'=> $GLOBALS['links']['dossier-archives']['linkvalue']);
		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_archives'].'">'.$GLOBALS['lang']['divers']['goto_archives'].'</a>'.END_LINE;
		echo '</div>';
	}
	
	/** Affichage du lien de consultation d'archives ( si nécessaire )
	*/
	if($GLOBALS['activeitem']=='dossier-archives')  {
		
		$link_archive= array('rub'=> $GLOBALS['links']['dossier']['linkvalue']);
		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_currentlist'].'">'.$GLOBALS['lang']['divers']['goto_currentlist'].'</a>'.END_LINE;
		echo '</div>';
	}
	
	/** Affichage du Listing Des Dossiers et Dossiers archivés
	*/
	if((isset($_REQUEST['id']) && isset($_REQUEST['filter'])) || (!isset($_REQUEST['id']) && !isset($_REQUEST['filter']))) 
	{	
		DisplayListPublication($statut, $filter, $id, $debut);
	}
	
	
	/** Détail d'un dossier
	*/
	if(isset($_REQUEST['id']) && !isset($_REQUEST['filter'])) {
		DisplayOnePublication($id);
		DisplayPublicationParts($id);
		echo '<div id="ressources">'.END_LINE;
		DisplayPublicationLinks($id);
		DisplayPublicationMulti($id);
		DisplayPublicationBiblio($id);
		echo '</div>'.END_LINE;
	}
}


//////////////////////////////////////////
/////affichage rapport de groupe de travail
//////////////////////////////////////////

if($GLOBALS['activeitem']=='rapport') {
	include_once('../workshoprep/display.php');
	
	/** préparation des variables
	* 	$id -> default -1
	**/
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	
	/** Détail d'un rapport
	*/
	if(isset($_REQUEST['id'])) {
		DisplayOneWorkshopRep($id, 'P');
		DisplayWorkshopRepParts($id);
		echo '<div id="ressources">'.END_LINE;
		DisplayWorkshopRepLinks($id);
		DisplayWorkshopRepBiblio($id);
		echo '</div>'.END_LINE;
	}
	
}


//////////////////////////////////////////
/////	affichage Parties par parties 
/////	Rapports de groupe de travail et Dossiers
//////////////////////////////////////////

if($GLOBALS['activeitem']=='rapport-partie' || $GLOBALS['activeitem']=='dossier-partie') {
	include_once('../contents/display.php');
	
	/** préparation des variables
	* 	$id -> default -1
	*   $parentid -> default -1
	**/
	
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['parentid'])) $parentid=$_REQUEST['parentid']; else $parentid=-1;
	
	/** Détail d'une partie
	*/
	if($GLOBALS['activeitem']=='rapport-partie')
	{
		include_once('../workshoprep/display.php');
		DisplayWorkshopNameAndGroup($parentid);
		DisplayWorkshopRepLinkinPart($id, $parentid, 'TEXT');
		DisplayOneWorkshopPart($id);
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkParts($id, $parentid, 'PREVIOUS', 'W');
		DisplayLinkParts($id, $parentid, 'NEXT', 'W');
		echo '</div>'.END_LINE;
		echo '<div id="ressources">'.END_LINE;
		DisplayWorkshopRepLinks($parentid);
		DisplayWorkshopRepBiblio($parentid);
		echo '</div>'.END_LINE;
		
	}
	if($GLOBALS['activeitem']=='dossier-partie') 
	{
		include_once('../publication/display.php');
		DisplayPublicationTitle($parentid);
		DisplayPublicationLinkinPart($id, $parentid, 'TEXT');
		DisplayOnePublicationPart($id);
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkParts($id, $parentid, 'PREVIOUS', 'P');
		DisplayLinkParts($id, $parentid, 'NEXT', 'P');
		echo '</div>'.END_LINE;
		echo '<div id="ressources">'.END_LINE;
		DisplayPublicationLinks($parentid);
		DisplayPublicationMulti($parentid);
		DisplayPublicationBiblio($parentid);
		echo '</div>'.END_LINE;
	}
	

	
}


//////////////////////////////////////////
/////affichage partie news
//////////////////////////////////////////

if($GLOBALS['activeitem']=='actualite' || $GLOBALS['activeitem']=='actualite-archives') {
	include_once('../news/display.php');
	/** préparation des variables
	* 	$statut
	* 	$debut default 0
	* 	$id -> default -1
	* 	$filter default -1
	**/
	if($GLOBALS['activeitem']=='actualite') $statut='public';
	if($GLOBALS['activeitem']=='actualite-archives') $statut='archives_p';
	if(isset($_REQUEST['id'])) $id=$_REQUEST['id']; else $id=-1;
	if(isset($_REQUEST['debut'])) $debut=$_REQUEST['debut']; else $debut=0;
	if(isset($_REQUEST['filter'])) {
		if($_REQUEST['filter']==$GLOBALS['filter']['echelle']['linkvalue']) $filter='SCALE';
		if($_REQUEST['filter']==$GLOBALS['filter']['theme']['linkvalue']) $filter='THEME';
		if($_REQUEST['filter']==$GLOBALS['filter']['niveau']['linkvalue']) $filter='LEVEL';
	} else $filter=-1;

	/** Affichage du lien de consultation d'archives ( si nécessaire )
	*/
	
	if($GLOBALS['activeitem']!='actualite-archives')  {

		$link_archive= array('rub'=> $GLOBALS['links']['actualite-archives']['linkvalue']);

		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_archives'].'">'.$GLOBALS['lang']['divers']['goto_archives'].'</a>'.END_LINE;
		echo '</div>';
		
	}
	
	
	/** Affichage du lien de consultation liste courante ( si nécessaire )
	*/
	if($GLOBALS['activeitem']=='actualite-archives')  {

		$link_archive= array('rub'=> $GLOBALS['links']['actualite']['linkvalue']);

		echo '<div class="switchnav">';
		echo '<a href="'.HrefMaker($link_archive).'" title="'.$GLOBALS['lang']['divers']['goto_currentlist'].'">'.$GLOBALS['lang']['divers']['goto_currentlist'].'</a>'.END_LINE;
		echo '</div>';
		
	}
	
	/** Affichage du Listing Actualité + Archives
	*/
	
	if((isset($_REQUEST['id']) && isset($_REQUEST['filter'])) || (!isset($_REQUEST['id']) && !isset($_REQUEST['filter']))) 
	{	
		DisplayListNews($statut, $filter, $id, $debut);
	}
	
	
	/** Détail d'une actualité
	*/
	if(isset($_REQUEST['id']) && !isset($_REQUEST['filter'])) {
		$news_statut=DisplayOneNews($id);
		echo '<hr />'.END_LINE;
		echo '<div class="nextprev">'.END_LINE;
		DisplayLinkNews($id, 'PREVIOUS', $news_statut);
		DisplayLinkNews($id, 'NEXT', $news_statut);
		echo '</div>'.END_LINE;
	}

	
}
?>
</div>
